yaml-schema is a library for validating YAML data against a JSON Schema.
Re-exports
pub use engine::Engine;pub use error::Error;pub use reference::Reference;pub use schemas::YamlSchema;pub use validation::Context;pub use validation::Validator;
Modules
- engine
- error
- loader
- The loader module loads the YAML schema from a file into the in-memory model
- reference
- schemas
- The schemas defined in YAML Schema
- utils
- Various utility functions
- validation
- The validation module contains the logic for validating a YAML schema against a YAML value
Macros
- circular_
reference - expected_
mapping - expected_
scalar - expected_
type_ is_ string - fail_
fast - generic_
error - schema_
loading_ error - unsupported_
type
Structs
- Root
Schema - A RootSchema represents the root document in a schema document, and includes additional
fields such as
$schemathat are not allowed in subschemas. It also provides a way to resolve references to other schemas.
Enums
- Const
Value - A ConstValue represents a constant value for the
constkeyword. Per JSON Schema,constcan be any JSON value: null, boolean, number, string, array, or object. - Number
- A Number is either an integer or a float