RootSchema

Struct RootSchema 

pub struct RootSchema {
    pub meta_schema: Option<String>,
    pub schema: YamlSchema,
    pub base_uri: Option<Url>,
}
A RootSchema represents the root document in a schema document, and includes additional fields such as $schema that are not allowed in subschemas. It also provides a way to resolve references to other schemas.

Fields

meta_schema: Option<String>schema: YamlSchemabase_uri: Option<Url>

Base URI for resolving relative $ref values (from file path, URL, or $id).

Implementations

Source

impl RootSchema

pub fn empty() -> Self

Create an empty RootSchema

pub fn new(schema: YamlSchema) -> Self

Create a new RootSchema with a given schema

pub fn id(&self) -> Option<String>

Returns the $id of the schema’s Subschema, if present.

pub fn cache_key(&self, fallback: &str) -> String

Returns the preferred key for caching this schema: $id if it is a valid URI, otherwise the given fallback (e.g. the file or fetch URI).

pub fn resolve(&self, pointer: &Pointer) -> Option<&YamlSchema>

Resolve a JSON Pointer to an element in the schema.