RootSchema

Struct RootSchema 

pub struct RootSchema<'r> {
    pub meta_schema: Option<String>,
    pub schema: YamlSchema<'r>,
}
A RootSchema represents the root document in a schema document, and includes additional fields such as $schema that are not allowed in subschemas. It also provides a way to resolve references to other schemas.

Fields

meta_schema: Option<String>schema: YamlSchema<'r>

Implementations

Source

impl<'r> RootSchema<'r>

pub fn empty() -> Self

Create an empty RootSchema

pub fn new(schema: YamlSchema<'r>) -> Self

Create a new RootSchema with a given schema

pub fn resolve(&self, pointer: &Pointer) -> Option<&YamlSchema<'_>>

Resolve a JSON Pointer to an element in the schema.